@@ -1,21 +1,19 @@
 # -*- coding: utf-8 -*-
-"""
-Created on Wed Apr 22 19:45:04 2020
+import multiprocessing as mp
+import os
 
-@author: msmsa
-"""
 import numpy as np
 import pandas as pd
-import os
-from .LCA_matrix import LCA_matrix
-import multiprocessing as mp
 from brightway2 import LCA, projects
 
+from .LCA_matrix import LCA_matrix
+
 
 class Monte_Carlo(LCA_matrix):
-    """Setups the Monte Carlo simulation. This class is inherited from ``swolfpy.LCA_matrix``. \n
-    The Monte Carlo simulation will be only done for  the process models, common data
-    or parameters than the class gets by arguments.
+    """
+    Setups the Monte Carlo simulation. This class is inherited from
+    ``swolfpy.LCA_matrix``. \n The Monte Carlo simulation will be only done for  the
+    process models, common data or parameters than the class gets by arguments.
 
     :param functional_unit: ``{flow:amount}``
     :type functional_unit: dict
@@ -40,10 +38,19 @@ class Monte_Carlo(LCA_matrix):
 
     :param seed: seed for ``stats_arrays.RandomNumberGenerator``
     :type seed: int, optional
-
     """
-    def __init__(self, functional_unit, method, project, process_models=None, process_model_names=None,
-                 common_data=None, parameters=None, seed=None):
+
+    def __init__(
+        self,
+        functional_unit,
+        method,
+        project,
+        process_models=None,
+        process_model_names=None,
+        common_data=None,
+        parameters=None,
+        seed=None,
+    ):
         super().__init__(functional_unit, method)
 
         self.process_models = process_models
@@ -57,37 +64,66 @@ class Monte_Carlo(LCA_matrix):
             self.seed = 0
 
     def run(self, nproc, n):
-        """ Runs the Monte Carlo ``n`` times with ``nproc`` processors. Calls and map the ``Monte_Carlo.worker()`` to the processors.
+        """
+        Runs the Monte Carlo ``n`` times with ``nproc`` processors. Calls and map the
+        ``Monte_Carlo.worker()`` to the processors.
 
         :param nproc: Number of processors allocated to MC
         :type nproc: int
         :param n: Number of iterations in MC
         :type n: int
-
         """
 
         def pool_adapter(x):
-            return(x)
+            return x
 
         with pool_adapter(mp.Pool(processes=nproc)) as pool:
-            res = pool.map(Monte_Carlo.worker,
-                           [(self.project, self.functional_unit, self.method, self.parameters, self.process_models,
-                             self.process_model_names, self.common_data, self.tech_matrix, self.bio_matrix, self.seed + i * 100, n // nproc)
-                            for i in range(nproc)])
+            res = pool.map(
+                Monte_Carlo.worker,
+                [
+                    (
+                        self.project,
+                        self.functional_unit,
+                        self.method,
+                        self.parameters,
+                        self.process_models,
+                        self.process_model_names,
+                        self.common_data,
+                        self.tech_matrix,
+                        self.bio_matrix,
+                        self.seed + i * 100,
+                        n // nproc,
+                    )
+                    for i in range(nproc)
+                ],
+            )
         self.results = [x for lst in res for x in lst]
-# =============================================================================
-#         res = Monte_Carlo.worker((self.project, self.functional_unit, self.method, self.parameters, self.process_models, self.process_model_names,
-#                                   self.common_data, self.tech_matrix, self.bio_matrix, self.seed, n//nproc))
-#         self.results = [x for lst in res for x in lst]
-# =============================================================================
+
+    # =============================================================================
+    #         res = Monte_Carlo.worker((self.project, self.functional_unit, self.method, self.parameters, self.process_models, self.process_model_names,
+    #                                   self.common_data, self.tech_matrix, self.bio_matrix, self.seed, n//nproc))
+    #         self.results = [x for lst in res for x in lst]
+    # =============================================================================
 
     @staticmethod
     def worker(args):
         """
-        Setups the Monte Carlo for process models and input data and then creates the ``LCA`` object
-        and Calls the ``Monte_Carlo.parallel_mc()`` for `n` times.
+        Setups the Monte Carlo for process models and input data and then creates the
+        ``LCA`` object and Calls the ``Monte_Carlo.parallel_mc()`` for `n` times.
         """
-        project, functional_unit, method, parameters, process_models, process_model_names, common_data, tech_matrix, bio_matrix, seed, n = args
+        (
+            project,
+            functional_unit,
+            method,
+            parameters,
+            process_models,
+            process_model_names,
+            common_data,
+            tech_matrix,
+            bio_matrix,
+            seed,
+            n,
+        ) = args
         projects.set_current(project, writable=False)
         if common_data:
             common_data.setup_MC(seed + 100000)
@@ -100,19 +136,41 @@ class Monte_Carlo(LCA_matrix):
         lca = LCA(functional_unit, method[0])
         lca.lci()
         lca.lcia()
-        return [Monte_Carlo.parallel_mc(lca, project, functional_unit, method, tech_matrix, bio_matrix, process_models=process_models,
-                process_model_names=process_model_names, parameters=parameters, common_data=common_data, index=x)
-                for x in range(n)]
+        return [
+            Monte_Carlo.parallel_mc(
+                lca,
+                method,
+                tech_matrix,
+                bio_matrix,
+                process_models=process_models,
+                process_model_names=process_model_names,
+                parameters=parameters,
+                common_data=common_data,
+                index=x,
+            )
+            for x in range(n)
+        ]
 
     @staticmethod
-    def parallel_mc(lca, project, functional_unit, method, tech_matrix, bio_matrix, process_models=None, process_model_names=None,
-                    parameters=None, common_data=None, index=None):
+    def parallel_mc(
+        lca,
+        method,
+        tech_matrix,
+        bio_matrix,
+        process_models=None,
+        process_model_names=None,
+        parameters=None,
+        common_data=None,
+        index=None,
+    ):
         """
-        Calls the ``InputData.gen_MC()`` , ``ProcessModel.MC_calc()``  and ``parameters.MC_calc()`` and then gets the new LCI and updates
-        the ``tech_matrix`` and ``bio_matrix``. Creates new ``bio_param`` and ``tech_param`` and then recalculate the LCA.
+        Calls the ``InputData.gen_MC()`` , ``ProcessModel.MC_calc()``  and
+        ``parameters.MC_calc()`` and then gets the new LCI and updates the ``tech_matrix``
+        and ``bio_matrix``.
 
+        Creates new ``bio_param`` and ``tech_param`` and then recalculate the LCA.
         """
-        uncertain_inputs = list()
+        uncertain_inputs = []
         if process_models:
             if common_data:
                 uncertain_inputs += common_data.gen_MC()
@@ -146,7 +204,7 @@ class Monte_Carlo(LCA_matrix):
         if lca.lcia:
             lca.lcia_calculation()
 
-        lca_results = dict()
+        lca_results = {}
         lca_results[method[0]] = lca.score
 
         if len(method) > 1:
@@ -156,11 +214,12 @@ class Monte_Carlo(LCA_matrix):
                 lca_results[method[i]] = lca.score
             lca.switch_method(method[0])
         print(os.getpid(), index)
-        return(os.getpid(), lca_results, uncertain_inputs)
+        return (os.getpid(), lca_results, uncertain_inputs)
 
     ### Export results
     def result_to_DF(self):
-        """ Returns the results from the Monte Carlo in a ``pandas.DataFrame`` format.
+        """
+        Returns the results from the Monte Carlo in a ``pandas.DataFrame`` format.
 
         :return: Monte Carlo results
         :rtype: ``pandas.DataFrame``
@@ -171,10 +230,13 @@ class Monte_Carlo(LCA_matrix):
             output[j] = [self.results[i][1][j] for i in range(len(self.results))]
         # Reporting the input data
         for j in range(len(self.results[0][2])):
-            output[self.results[0][2][j][0]] = [self.results[i][2][j][1] for i in range(len(self.results))]
-        return(output)
+            output[self.results[0][2][j][0]] = [
+                self.results[i][2][j][1] for i in range(len(self.results))
+            ]
+        return output
 
     def save_results(self, name):
-        """ Save the results from the Monte Carlo to pickle file.
+        """
+        Save the results from the Monte Carlo to pickle file.
         """
         self.result_to_DF().to_pickle(name)
